==> jena-5.4.0-source-release.zip: jena-5.4.0/jena-arq/src/test/java/org/apache/jena/sparql/core/mem/TestDatasetGraphInMemoryTransactions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.core.mem;

import org.apache.jena.atlas.logging.LogCtl ;
import org.apache.jena.query.Dataset ;
import org.apache.jena.query.DatasetFactory ;
import org.apache.jena.sparql.transaction.AbstractTestTransactionLifecycle ;
import org.junit.AfterClass ;
import org.junit.BeforeClass ;

public class TestDatasetGraphInMemoryTransactions extends AbstractTestTransactionLifecycle {
    static Class<?> targetClassLogger = DatasetGraphInMemory.class ;
    @BeforeClass public static void beforeClassLoggingOff() { LogCtl.disable(targetClassLogger) ; } 
    @AfterClass public static void afterClassLoggingOn()    { LogCtl.setInfo(targetClassLogger) ; }
    
	@Override
	protected Dataset create() {
		return DatasetFactory.createTxnMem();
	}
}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-arq/src/test/java/org/apache/jena/sparql/core/mem/TestDatasetGraphInMemoryTransactions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.core.mem;

import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.BeforeAll;

import org.apache.jena.atlas.logging.LogCtl;
import org.apache.jena.query.Dataset;
import org.apache.jena.query.DatasetFactory;
import org.apache.jena.sparql.transaction.AbstractTestTransactionLifecycle;

public class TestDatasetGraphInMemoryTransactions extends AbstractTestTransactionLifecycle {
    static Class<?> targetClassLogger = DatasetGraphInMemory.class;
    @BeforeAll public static void beforeClassLoggingOff() { LogCtl.disable(targetClassLogger); }
    @AfterAll public static void afterClassLoggingOn()    { LogCtl.setInfo(targetClassLogger); }

	@Override
	protected Dataset create() {
		return DatasetFactory.createTxnMem();
	}
}
